package sfnt

var (
	// tableTags contains to list of table tags.
	// https://www.microsoft.com/typography/otspec/otff.htm
	tableTags = map[string]string{
		// Required Tables
		"cmap": "Character to glyph mapping",
		"head": "Font header",
		"hhea": "Horizontal header",
		"hmtx": "Horizontal metrics",
		"maxp": "Maximum profile",
		"name": "Naming table",
		"OS/2": "OS/2 and Windows specific metrics",
		"post": "PostScript information",

		// Tables Related to TrueType Outlines
		"cvt ": "Control Value Table (optional table)",
		"fpgm": "Font program (optional table)",
		"glyf": "Glyph data",
		"loca": "Index to location",
		"prep": "CVT Program (optional table)",
		"gasp": "Grid-fitting/Scan-conversion (optional table)",

		// Tables Related to CFF Outlines
		"CFF ": "Compact Font Format 1.0",
		"CFF2": "Compact Font Format 2.0",
		"VORG": "Vertical Origin (optional table)",

		// Table related to SVG outlines
		"SVG": "The SVG (Scalable Vector Graphics) table",

		// Tables Related to Bitmap Glyphs
		"EBDT": "Embedded bitmap data",
		"EBLC": "Embedded bitmap location data",
		"EBSC": "Embedded bitmap scaling data",
		"CBDT": "Color bitmap data",
		"CBLC": "Color bitmap location data",
		"sbix": "Standard bitmap graphics",

		// Advanced Typographic Tables
		"BASE": "Baseline data",
		"GDEF": "Glyph definition data",
		"GPOS": "Glyph positioning data",
		"GSUB": "Glyph substitution data",
		"JSTF": "Justification data",
		"MATH": "Math layout data",

		// Tables used for OpenType Font Variations
		"avar": "Axis variations",
		"cvar": "CVT variations (TrueType outlines only)",
		"fvar": "Font variations",
		"gvar": "Glyph variations (TrueType outlines only)",
		"HVAR": "Horizontal metrics variations",
		"MVAR": "Metrics variations",
		"STAT": "Style attributes (required for variable fonts, optional for non-variable fonts)",
		"VVAR": "Vertical metrics variations",

		// Tables Related to Color Fonts
		"COLR": "Color table",
		"CPAL": "Color palette table",

		// Other OpenType Tables
		"DSIG": "Digital signature",
		"hdmx": "Horizontal device metrics",
		"kern": "Kerning",
		"LTSH": "Linear threshold data",
		"MERG": "Merge",
		"meta": "Metadata",
		"PCLT": "PCL 5 data",
		"VDMX": "Vertical device metrics",
		"vhea": "Vertical Metrics header",
		"vmtx": "Vertical Metrics",
	}

	// languageTags contains the registered language names mapped by tag.
	// See https://www.microsoft.com/typography/otspec/languagetags.htm
	languageTags = map[string]string{
		"ABA ": "Abaza",
		"ABK ": "Abkhazian",
		"ACH ": "Acholi",
		"ACR ": "Achi",
		"ADY ": "Adyghe",
		"AFK ": "Afrikaans",
		"AFR ": "Afar",
		"AGW ": "Agaw",
		"AIO ": "Aiton",
		"AKA ": "Akan",
		"ALS ": "Alsatian",
		"ALT ": "Altai",
		"AMH ": "Amharic",
		"ANG ": "Anglo-Saxon",
		"APPH": "Phonetic transcription—Americanist conventions",
		"ARA ": "Arabic",
		"ARG ": "Aragonese",
		"ARI ": "Aari",
		"ARK ": "Rakhine",
		"ASM ": "Assamese",
		"AST ": "Asturian",
		"ATH ": "Athapaskan",
		"AVR ": "Avar",
		"AWA ": "Awadhi",
		"AYM ": "Aymara",
		"AZB ": "Torki",
		"AZE ": "Azerbaijani",
		"BAD ": "Badaga",
		"BAD0": "Banda",
		"BAG ": "Baghelkhandi",
		"BAL ": "Balkar",
		"BAN ": "Balinese",
		"BAR ": "Bavarian",
		"BAU ": "Baulé",
		"BBC ": "Batak Toba",
		"BBR ": "Berber",
		"BCH ": "Bench",
		"BCR ": "Bible Cree",
		"BDY ": "Bandjalang",
		"BEL ": "Belarussian",
		"BEM ": "Bemba",
		"BEN ": "Bengali",
		"BGC ": "Haryanvi",
		"BGQ ": "Bagri",
		"BGR ": "Bulgarian",
		"BHI ": "Bhili",
		"BHO ": "Bhojpuri",
		"BIK ": "Bikol",
		"BIL ": "Bilen",
		"BIS ": "Bislama",
		"BJJ ": "Kanauji",
		"BKF ": "Blackfoot",
		"BLI ": "Baluchi",
		"BLK ": "Pa'o Karen",
		"BLN ": "Balante",
		"BLT ": "Balti",
		"BMB ": "Bambara (Bamanankan)",
		"BML ": "Bamileke",
		"BOS ": "Bosnian",
		"BPY ": "Bishnupriya Manipuri",
		"BRE ": "Breton",
		"BRH ": "Brahui",
		"BRI ": "Braj Bhasha",
		"BRM ": "Burmese",
		"BRX ": "Bodo",
		"BSH ": "Bashkir",
		"BSK ": "Burushaski",
		"BTI ": "Beti",
		"BTS ": "Batak Simalungun",
		"BUG ": "Bugis",
		"BYV ": "Medumba",
		"CAK ": "Kaqchikel",
		"CAT ": "Catalan",
		"CBK ": "Zamboanga Chavacano",
		"CCHN": "Chinantec",
		"CEB ": "Cebuano",
		"CHE ": "Chechen",
		"CHG ": "Chaha Gurage",
		"CHH ": "Chattisgarhi",
		"CHI ": "Chichewa (Chewa, Nyanja)",
		"CHK ": "Chukchi",
		"CHK0": "Chuukese",
		"CHO ": "Choctaw",
		"CHP ": "Chipewyan",
		"CHR ": "Cherokee",
		"CHA ": "Chamorro",
		"CHU ": "Chuvash",
		"CHY ": "Cheyenne",
		"CGG ": "Chiga",
		"CJA ": "Western Cham",
		"CJM ": "Eastern Cham",
		"CMR ": "Comorian",
		"COP ": "Coptic",
		"COR ": "Cornish",
		"COS ": "Corsican",
		"CPP ": "Creoles",
		"CRE ": "Cree",
		"CRR ": "Carrier",
		"CRT ": "Crimean Tatar",
		"CSB ": "Kashubian",
		"CSL ": "Church Slavonic",
		"CSY ": "Czech",
		"CTG ": "Chittagonian",
		"CUK ": "San Blas Kuna",
		"DAN ": "Danish",
		"DAR ": "Dargwa",
		"DAX ": "Dayi",
		"DCR ": "Woods Cree",
		"DEU ": "German",
		"DGO ": "Dogri",
		"DGR ": "Dogri",
		"DHG ": "Dhangu",
		"DHV ": "E!	Divehi (Dhivehi, Maldivian) (deprecated)",
		"DIQ ": "Dimli",
		"DIV ": "Divehi (Dhivehi, Maldivian)",
		"DJR ": "Zarma",
		"DJR0": "Djambarrpuyngu",
		"DNG ": "Dangme",
		"DNJ ": "Dan",
		"DNK ": "Dinka",
		"DRI ": "Dari",
		"DUJ ": "Dhuwal",
		"DUN ": "Dungan",
		"DZN ": "Dzongkha",
		"EBI ": "Ebira",
		"ECR ": "Eastern Cree",
		"EDO ": "Edo",
		"EFI ": "Efik",
		"ELL ": "Greek",
		"EMK ": "Eastern Maninkakan",
		"ENG ": "English",
		"ERZ ": "Erzya",
		"ESP ": "Spanish",
		"ESU ": "Central Yupik",
		"ETI ": "Estonian",
		"EUQ ": "Basque",
		"EVK ": "Evenki",
		"EVN ": "Even",
		"EWE ": "Ewe",
		"FAN ": "French Antillean",
		"FAN0": "Fang",
		"FAR ": "Persian",
		"FAT ": "Fanti",
		"FIN ": "Finnish",
		"FJI ": "Fijian",
		"FLE ": "Dutch (Flemish)",
		"FMP ": "Fe'fe'",
		"FNE ": "Forest Nenets",
		"FON ": "Fon",
		"FOS ": "Faroese",
		"FRA ": "French",
		"FRC ": "Cajun French",
		"FRI ": "Frisian",
		"FRL ": "Friulian",
		"FRP ": "Arpitan",
		"FTA ": "Futa",
		"FUL ": "Fulah",
		"FUV ": "Nigerian Fulfulde",
		"GAD ": "Ga",
		"GAE ": "Scottish Gaelic (Gaelic)",
		"GAG ": "Gagauz",
		"GAL ": "Galician",
		"GAR ": "Garshuni",
		"GAW ": "Garhwali",
		"GEZ ": "Ge'ez",
		"GIH ": "Githabul",
		"GIL ": "Gilyak",
		"GIL0": "Kiribati (Gilbertese)",
		"GKP ": "Kpelle (Guinea)",
		"GLK ": "Gilaki",
		"GMZ ": "Gumuz",
		"GNN ": "Gumatj",
		"GOG ": "Gogo",
		"GON ": "Gondi",
		"GRN ": "Greenlandic",
		"GRO ": "Garo",
		"GUA ": "Guarani",
		"GUC ": "Wayuu",
		"GUF ": "Gupapuyngu",
		"GUJ ": "Gujarati",
		"GUZ ": "Gusii",
		"HAI ": "Haitian (Haitian Creole)",
		"HAL ": "Halam",
		"HAR ": "Harauti",
		"HAU ": "Hausa",
		"HAW ": "Hawaiian",
		"HAY ": "Haya",
		"HAZ ": "Hazaragi",
		"HBN ": "Hammer-Banna",
		"HER ": "Herero",
		"HIL ": "Hiligaynon",
		"HIN ": "Hindi",
		"HMA ": "High Mari",
		"HMN ": "Hmong",
		"HMO ": "Hiri Motu",
		"HND ": "Hindko",
		"HO  ": "Ho",
		"HRI ": "Harari",
		"HRV ": "Croatian",
		"HUN ": "Hungarian",
		"HYE ": "Armenian",
		"HYE0": "Armenian East",
		"IBA ": "Iban",
		"IBB ": "Ibibio",
		"IBO ": "Igbo",
		"IJO ": "Ijo languages",
		"IDO ": "Ido",
		"ILE ": "Interlingue",
		"ILO ": "Ilokano",
		"INA ": "Interlingua",
		"IND ": "Indonesian",
		"ING ": "Ingush",
		"INU ": "Inuktitut",
		"IPK ": "Inupiat",
		"IPPH": "Phonetic transcription—IPA conventions",
		"IRI ": "Irish",
		"IRT ": "Irish Traditional",
		"ISL ": "Icelandic",
		"ISM ": "Inari Sami",
		"ITA ": "Italian",
		"IWR ": "Hebrew",
		"JAM ": "Jamaican Creole",
		"JAN ": "Japanese",
		"JAV ": "Javanese",
		"JBO ": "Lojban",
		"JCT ": "Krymchak",
		"JII ": "Yiddish",
		"JUD ": "Ladino",
		"JUL ": "Jula",
		"KAB ": "Kabardian",
		"KAB0": "Kabyle",
		"KAC ": "Kachchi",
		"KAL ": "Kalenjin",
		"KAN ": "Kannada",
		"KAR ": "Karachay",
		"KAT ": "Georgian",
		"KAZ ": "Kazakh",
		"KDE ": "Makonde",
		"KEA ": "Kabuverdianu (Crioulo)",
		"KEB ": "Kebena",
		"KEK ": "Kekchi",
		"KGE ": "Khutsuri Georgian",
		"KHA ": "Khakass",
		"KHK ": "Khanty-Kazim",
		"KHM ": "Khmer",
		"KHS ": "Khanty-Shurishkar",
		"KHT ": "Khamti Shan",
		"KHV ": "Khanty-Vakhi",
		"KHW ": "Khowar",
		"KIK ": "Kikuyu (Gikuyu)",
		"KIR ": "Kirghiz (Kyrgyz)",
		"KIS ": "Kisii",
		"KIU ": "Kirmanjki",
		"KJD ": "Southern Kiwai",
		"KJP ": "Eastern Pwo Karen",
		"KKN ": "Kokni",
		"KLM ": "Kalmyk",
		"KMB ": "Kamba",
		"KMN ": "Kumaoni",
		"KMO ": "Komo",
		"KMS ": "Komso",
		"KMZ ": "Khorasani Turkic",
		"KNR ": "Kanuri",
		"KOD ": "Kodagu",
		"KOH ": "Korean Old Hangul",
		"KOK ": "Konkani",
		"KON ": "Kikongo",
		"KOM ": "Komi",
		"KON0": "Kongo",
		"KOP ": "Komi-Permyak",
		"KOR ": "Korean",
		"KOS ": "Kosraean",
		"KOZ ": "Komi-Zyrian",
		"KPL ": "Kpelle",
		"KRI ": "Krio",
		"KRK ": "Karakalpak",
		"KRL ": "Karelian",
		"KRM ": "Karaim",
		"KRN ": "Karen",
		"KRT ": "Koorete",
		"KSH ": "Kashmiri",
		"KSH0": "Ripuarian",
		"KSI ": "Khasi",
		"KSM ": "Kildin Sami",
		"KSW ": "S’gaw Karen",
		"KUA ": "Kuanyama",
		"KUI ": "Kui",
		"KUL ": "Kulvi",
		"KUM ": "Kumyk",
		"KUR ": "Kurdish",
		"KUU ": "Kurukh",
		"KUY ": "Kuy",
		"KYK ": "Koryak",
		"KYU ": "Western Kayah",
		"LAD ": "Ladin",
		"LAH ": "Lahuli",
		"LAK ": "Lak",
		"LAM ": "Lambani",
		"LAO ": "Lao",
		"LAT ": "Latin",
		"LAZ ": "Laz",
		"LCR ": "L-Cree",
		"LDK ": "Ladakhi",
		"LEZ ": "Lezgi",
		"LIJ ": "Ligurian",
		"LIM ": "Limburgish",
		"LIN ": "Lingala",
		"LIS ": "Lisu",
		"LJP ": "Lampung",
		"LKI ": "Laki",
		"LMA ": "Low Mari",
		"LMB ": "Limbu",
		"LMO ": "Lombard",
		"LMW ": "Lomwe",
		"LOM ": "Loma",
		"LRC ": "Luri",
		"LSB ": "Lower Sorbian",
		"LSM ": "Lule Sami",
		"LTH ": "Lithuanian",
		"LTZ ": "Luxembourgish",
		"LUA ": "Luba-Lulua",
		"LUB ": "Luba-Katanga",
		"LUG ": "Ganda",
		"LUH ": "Luyia",
		"LUO ": "Luo",
		"LVI ": "Latvian",
		"MAD ": "Madura",
		"MAG ": "Magahi",
		"MAH ": "Marshallese",
		"MAJ ": "Majang",
		"MAK ": "Makhuwa",
		"MAL ": "Malayalam",
		"MAM ": "Mam",
		"MAN ": "Mansi",
		"MAP ": "Mapudungun",
		"MAR ": "Marathi",
		"MAW ": "Marwari",
		"MBN ": "Mbundu",
		"MBO ": "Mbo",
		"MCH ": "Manchu",
		"MCR ": "Moose Cree",
		"MDE ": "Mende",
		"MDR ": "Mandar",
		"MEN ": "Me'en",
		"MER ": "Meru",
		"MFE ": "Morisyen",
		"MIN ": "Minangkabau",
		"MIZ ": "Mizo",
		"MKD ": "Macedonian",
		"MKR ": "Makasar",
		"MKW ": "Kituba",
		"MLE ": "Male",
		"MLG ": "Malagasy",
		"MLN ": "Malinke",
		"MLR ": "Malayalam Reformed",
		"MLY ": "Malay",
		"MND ": "Mandinka",
		"MNG ": "Mongolian",
		"MNI ": "Manipuri",
		"MNK ": "Maninka",
		"MNX ": "Manx",
		"MOH ": "Mohawk",
		"MOK ": "Moksha",
		"MOL ": "Moldavian",
		"MON ": "Mon",
		"MOR ": "Moroccan",
		"MOS ": "Mossi",
		"MRI ": "Maori",
		"MTH ": "Maithili",
		"MTS ": "Maltese",
		"MUN ": "Mundari",
		"MUS ": "Muscogee",
		"MWL ": "Mirandese",
		"MWW ": "Hmong Daw",
		"MYN ": "Mayan",
		"MZN ": "Mazanderani",
		"NAG ": "Naga-Assamese",
		"NAH ": "Nahuatl",
		"NAN ": "Nanai",
		"NAP ": "Neapolitan",
		"NAS ": "Naskapi",
		"NAU ": "Nauruan",
		"NAV ": "Navajo",
		"NCR ": "N-Cree",
		"NDB ": "Ndebele",
		"NDC ": "Ndau",
		"NDG ": "Ndonga",
		"NDS ": "Low Saxon",
		"NEP ": "Nepali",
		"NEW ": "Newari",
		"NGA ": "Ngbaka",
		"NGR ": "Nagari",
		"NHC ": "Norway House Cree",
		"NIS ": "Nisi",
		"NIU ": "Niuean",
		"NKL ": "Nyankole",
		"NKO ": "N'Ko",
		"NLD ": "Dutch",
		"NOE ": "Nimadi",
		"NOG ": "Nogai",
		"NOR ": "Norwegian",
		"NOV ": "Novial",
		"NSM ": "Northern Sami",
		"NSO ": "Sotho, Northern",
		"NTA ": "Northern Tai",
		"NTO ": "Esperanto",
		"NYM ": "Nyamwezi",
		"NYN ": "Norwegian Nynorsk (Nynorsk, Norwegian)",
		"NZA ": "Mbembe Tigon",
		"OCI ": "Occitan",
		"OCR ": "Oji-Cree",
		"OJB ": "Ojibway",
		"ORI ": "Odia (formerly Oriya)",
		"ORO ": "Oromo",
		"OSS ": "Ossetian",
		"PAA ": "Palestinian Aramaic",
		"PAG ": "Pangasinan",
		"PAL ": "Pali",
		"PAM ": "Pampangan",
		"PAN ": "Punjabi",
		"PAP ": "Palpa",
		"PAP0": "Papiamentu",
		"PAS ": "Pashto",
		"PAU ": "Palauan",
		"PCC ": "Bouyei",
		"PCD ": "Picard",
		"PDC ": "Pennsylvania German",
		"PGR ": "Polytonic Greek",
		"PHK ": "Phake",
		"PIH ": "Norfolk",
		"PIL ": "Filipino",
		"PLG ": "Palaung",
		"PLK ": "Polish",
		"PMS ": "Piemontese",
		"PNB ": "Western Panjabi",
		"POH ": "Pocomchi",
		"PON ": "Pohnpeian",
		"PRO ": "Provencal",
		"PTG ": "Portuguese",
		"PWO ": "Western Pwo Karen",
		"QIN ": "Chin",
		"QUC ": "K’iche’",
		"QUH ": "Quechua (Bolivia)",
		"QUZ ": "Quechua",
		"QVI ": "Quechua (Ecuador)",
		"QWH ": "Quechua (Peru)",
		"RAJ ": "Rajasthani",
		"RAR ": "Rarotongan",
		"RBU ": "Russian Buriat",
		"RCR ": "R-Cree",
		"REJ ": "Rejang",
		"RIA ": "Riang",
		"RIF ": "Tarifit",
		"RIT ": "Ritarungo",
		"RKW ": "Arakwal",
		"RMS ": "Romansh",
		"RMY ": "Vlax Romani",
		"ROM ": "Romanian",
		"ROY ": "Romany",
		"RSY ": "Rusyn",
		"RTM ": "Rotuman",
		"RUA ": "Kinyarwanda",
		"RUN ": "Rundi",
		"RUP ": "Aromanian",
		"RUS ": "Russian",
		"SAD ": "Sadri",
		"SAN ": "Sanskrit",
		"SAS ": "Sasak",
		"SAT ": "Santali",
		"SAY ": "Sayisi",
		"SCN ": "Sicilian",
		"SCO ": "Scots",
		"SEK ": "Sekota",
		"SEL ": "Selkup",
		"SGA ": "Old Irish",
		"SGO ": "Sango",
		"SGS ": "Samogitian",
		"SHI ": "Tachelhit",
		"SHN ": "Shan",
		"SIB ": "Sibe",
		"SID ": "Sidamo",
		"SIG ": "Silte Gurage",
		"SKS ": "Skolt Sami",
		"SKY ": "Slovak",
		"SCS ": "North Slavey",
		"SLA ": "Slavey",
		"SLV ": "Slovenian",
		"SML ": "Somali",
		"SMO ": "Samoan",
		"SNA ": "Sena",
		"SNA0": "Shona",
		"SND ": "Sindhi",
		"SNH ": "Sinhala (Sinhalese)",
		"SNK ": "Soninke",
		"SOG ": "Sodo Gurage",
		"SOP ": "Songe",
		"SOT ": "Sotho, Southern",
		"SQI ": "Albanian",
		"SRB ": "Serbian",
		"SRD ": "Sardinian",
		"SRK ": "Saraiki",
		"SRR ": "Serer",
		"SSL ": "South Slavey",
		"SSM ": "Southern Sami",
		"STQ ": "Saterland Frisian",
		"SUK ": "Sukuma",
		"SUN ": "Sundanese",
		"SUR ": "Suri",
		"SVA ": "Svan",
		"SVE ": "Swedish",
		"SWA ": "Swadaya Aramaic",
		"SWK ": "Swahili",
		"SWZ ": "Swati",
		"SXT ": "Sutu",
		"SXU ": "Upper Saxon",
		"SYL ": "Sylheti",
		"SYR ": "Syriac",
		"SYRE": "Syriac, Estrangela script-variant (equivalent to ISO 15924 'Syre')",
		"SYRJ": "Syriac, Western script-variant (equivalent to ISO 15924 'Syrj')",
		"SYRN": "Syriac, Eastern script-variant (equivalent to ISO 15924 'Syrn')",
		"SZL ": "Silesian",
		"TAB ": "Tabasaran",
		"TAJ ": "Tajiki",
		"TAM ": "Tamil",
		"TAT ": "Tatar",
		"TCR ": "TH-Cree",
		"TDD ": "Dehong Dai",
		"TEL ": "Telugu",
		"TET ": "Tetum",
		"TGL ": "Tagalog",
		"TGN ": "Tongan",
		"TGR ": "Tigre",
		"TGY ": "Tigrinya",
		"THA ": "Thai",
		"THT ": "Tahitian",
		"TIB ": "Tibetan",
		"TIV ": "Tiv",
		"TKM ": "Turkmen",
		"TMH ": "Tamashek",
		"TMN ": "Temne",
		"TNA ": "Tswana",
		"TNE ": "Tundra Nenets",
		"TNG ": "Tonga",
		"TOD ": "Todo",
		"TOD0": "Toma",
		"TPI ": "Tok Pisin",
		"TRK ": "Turkish",
		"TSG ": "Tsonga",
		"TUA ": "Turoyo Aramaic",
		"TUM ": "Tulu",
		"TUL ": "Tumbuka",
		"TUV ": "Tuvin",
		"TVL ": "Tuvalu",
		"TWI ": "Twi",
		"TYZ ": "Tày",
		"TZM ": "Tamazight",
		"TZO ": "Tzotzil",
		"UDM ": "Udmurt",
		"UKR ": "Ukrainian",
		"UMB ": "Umbundu",
		"URD ": "Urdu",
		"USB ": "Upper Sorbian",
		"UYG ": "Uyghur",
		"UZB ": "Uzbek",
		"VEC ": "Venetian",
		"VEN ": "Venda",
		"VIT ": "Vietnamese",
		"VOL ": "Volapük",
		"VRO ": "Võro",
		"WA  ": "Wa",
		"WAG ": "Wagdi",
		"WAR ": "Waray-Waray",
		"WCR ": "West-Cree",
		"WEL ": "Welsh",
		"WLN ": "Walloon",
		"WLF ": "Wolof",
		"WTM ": "Mewati",
		"XBD ": "Lü",
		"XHS ": "Xhosa",
		"XJB ": "Minjangbal",
		"XOG ": "Soga",
		"XPE ": "Kpelle (Liberia)",
		"YAK ": "Sakha",
		"YAO ": "Yao",
		"YAP ": "Yapese",
		"YBA ": "Yoruba",
		"YCR ": "Y-Cree",
		"YIC ": "Yi Classic",
		"YIM ": "Yi Modern",
		"ZEA ": "Zealandic",
		"ZGH ": "Standard Morrocan Tamazigh",
		"ZHA ": "Zhuang",
		"ZHH ": "Chinese, Hong Kong SAR",
		"ZHP ": "Chinese Phonetic",
		"ZHS ": "Chinese Simplified",
		"ZHT ": "Chinese Traditional",
		"ZND ": "Zande",
		"ZUL ": "Zulu",
		"ZZA ": "Zazaki",
	}

	// scriptTags contains the registered script names mapped by tag.
	// See https://www.microsoft.com/typography/otspec/scripttags.htm
	scriptTags = map[string]string{
		"adlm": "Adlam",
		"ahom": "Ahom",
		"hluw": "Anatolian Hieroglyphs",
		"arab": "Arabic",
		"armn": "Armenian",
		"avst": "Avestan",
		"bali": "Balinese",
		"bamu": "Bamum",
		"bass": "Bassa Vah",
		"batk": "Batak",
		"beng": "Bengali",
		"bng2": "Bengali v.2",
		"bhks": "Bhaiksuki",
		"bopo": "Bopomofo",
		"brah": "Brahmi",
		"brai": "Braille",
		"bugi": "Buginese",
		"buhd": "Buhid",
		"byzm": "Byzantine Music",
		"cans": "Canadian Syllabics",
		"cari": "Carian",
		"aghb": "Caucasian Albanian",
		"cakm": "Chakma",
		"cham": "Cham",
		"cher": "Cherokee",
		"hani": "CJK Ideographic",
		"copt": "Coptic",
		"cprt": "Cypriot Syllabary",
		"cyrl": "Cyrillic",
		"DFLT": "Default",
		"dsrt": "Deseret",
		"deva": "Devanagari",
		"dev2": "Devanagari v.2",
		"dupl": "Duployan",
		"egyp": "Egyptian Hieroglyphs",
		"elba": "Elbasan",
		"ethi": "Ethiopic",
		"geor": "Georgian",
		"glag": "Glagolitic",
		"goth": "Gothic",
		"gran": "Grantha",
		"grek": "Greek",
		"gujr": "Gujarati",
		"gjr2": "Gujarati v.2",
		"guru": "Gurmukhi",
		"gur2": "Gurmukhi v.2",
		"hang": "Hangul",
		"jamo": "Hangul Jamo",
		"hano": "Hanunoo",
		"hatr": "Hatran",
		"hebr": "Hebrew",
		"kana": "Hiragana + Katakana",
		"armi": "Imperial Aramaic",
		"phli": "Inscriptional Pahlavi",
		"prti": "Inscriptional Parthian",
		"java": "Javanese",
		"kthi": "Kaithi",
		"knda": "Kannada",
		"knd2": "Kannada v.2",
		"kali": "Kayah Li",
		"khar": "Kharosthi",
		"khmr": "Khmer",
		"khoj": "Khojki",
		"sind": "Khudawadi",
		"lao ": "Lao",
		"latn": "Latin",
		"lepc": "Lepcha",
		"limb": "Limbu",
		"lina": "Linear A",
		"linb": "Linear B",
		"lisu": "Lisu (Fraser)",
		"lyci": "Lycian",
		"lydi": "Lydian",
		"mahj": "Mahajani",
		"mlym": "Malayalam",
		"mlm2": "Malayalam v.2",
		"mand": "Mandaic, Mandaean",
		"mani": "Manichaean",
		"marc": "Marchen",
		"math": "Mathematical Alphanumeric Symbols",
		"mtei": "Meitei Mayek (Meithei, Meetei)",
		"mend": "Mende Kikakui",
		"merc": "Meroitic Cursive",
		"mero": "Meroitic Hieroglyphs",
		"plrd": "Miao",
		"modi": "Modi",
		"mong": "Mongolian",
		"mroo": "Mro",
		"mult": "Multani",
		"musc": "Musical Symbols",
		"mymr": "Myanmar",
		"mym2": "Myanmar v.2",
		"nbat": "Nabataean",
		"newa": "Newa",
		"talu": "New Tai Lue",
		"nko ": "N'Ko",
		"orya": "Odia (formerly Oriya)",
		"ory2": "Odia v.2 (formerly Oriya v.2)",
		"ogam": "Ogham",
		"olck": "Ol Chiki",
		"ital": "Old Italic",
		"hung": "Old Hungarian",
		"narb": "Old North Arabian",
		"perm": "Old Permic",
		"xpeo": "Old Persian Cuneiform",
		"sarb": "Old South Arabian",
		"orkh": "Old Turkic, Orkhon Runic",
		"osge": "Osage",
		"osma": "Osmanya",
		"hmng": "Pahawh Hmong",
		"palm": "Palmyrene",
		"pauc": "Pau Cin Hau",
		"phag": "Phags-pa",
		"phnx": "Phoenician",
		"phlp": "Psalter Pahlavi",
		"rjng": "Rejang",
		"runr": "Runic",
		"samr": "Samaritan",
		"saur": "Saurashtra",
		"shrd": "Sharada",
		"shaw": "Shavian",
		"sidd": "Siddham",
		"sgnw": "Sign Writing",
		"sinh": "Sinhala",
		"sora": "Sora Sompeng",
		"xsux": "Sumero-Akkadian Cuneiform",
		"sund": "Sundanese",
		"sylo": "Syloti Nagri",
		"syrc": "Syriac",
		"tglg": "Tagalog",
		"tagb": "Tagbanwa",
		"tale": "Tai Le",
		"lana": "Tai Tham (Lanna)",
		"tavt": "Tai Viet",
		"takr": "Takri",
		"taml": "Tamil",
		"tml2": "Tamil v.2",
		"tang": "Tangut",
		"telu": "Telugu",
		"tel2": "Telugu v.2",
		"thaa": "Thaana",
		"thai": "Thai",
		"tibt": "Tibetan",
		"tfng": "Tifinagh",
		"tirh": "Tirhuta",
		"ugar": "Ugaritic Cuneiform",
		"vai ": "Vai",
		"wara": "Warang Citi",
		"yi  ": "Yi",
	}

	// featureTags contains the registered feature names mapped by tag.
	// See https://www.microsoft.com/typography/otspec/featurelist.htm
	featureTags = map[string]string{
		"aalt": "Access All Alternates",
		"abvf": "Above-base Forms",
		"abvm": "Above-base Mark Positioning",
		"abvs": "Above-base Substitutions",
		"afrc": "Alternative Fractions",
		"akhn": "Akhands",
		"blwf": "Below-base Forms",
		"blwm": "Below-base Mark Positioning",
		"blws": "Below-base Substitutions",
		"c2pc": "Petite Capitals From Capitals",
		"c2sc": "Small Capitals From Capitals",
		"calt": "Contextual Alternates",
		"case": "Case-Sensitive Forms",
		"ccmp": "Glyph Composition / Decomposition",
		"cfar": "Conjunct Form After Ro",
		"cjct": "Conjunct Forms",
		"clig": "Contextual Ligatures",
		"cpct": "Centered CJK Punctuation",
		"cpsp": "Capital Spacing",
		"crcy": "Currency (Deprecated)",
		"cswh": "Contextual Swash",
		"curs": "Cursive Positioning",
		// "cv01"..."cv99": "Character Variants N", // Handled in Feature.String()
		"dist": "Distances",
		"dlig": "Discretionary Ligatures",
		"dnom": "Denominators",
		"dpng": "Diphthongs (Deprecated)",
		"dtls": "Dotless Forms",
		"expt": "Expert Forms",
		"falt": "Final Glyph on Line Alternates",
		"fin2": "Terminal Forms #2",
		"fin3": "Terminal Forms #3",
		"fina": "Terminal Forms",
		"flac": "Flattened accent forms",
		"frac": "Fractions",
		"fwid": "Full Widths",
		"half": "Half Forms",
		"haln": "Halant Forms",
		"halt": "Alternate Half Widths",
		"hist": "Historical Forms",
		"hkna": "Horizontal Kana Alternates",
		"hlig": "Historical Ligatures",
		"hngl": "Hangul",
		"hojo": "Hojo Kanji Forms (JIS X 0212-1990 Kanji Forms)",
		"hwid": "Half Widths",
		"init": "Initial Forms",
		"isol": "Isolated Forms",
		"ital": "Italics",
		"jajp": "Japanese Forms (Deprecated)",
		"jalt": "Justification Alternates",
		"jp04": "JIS2004 Forms",
		"jp78": "JIS78 Forms",
		"jp83": "JIS83 Forms",
		"jp90": "JIS90 Forms",
		"kern": "Kerning",
		"kokr": "Korean Forms (Deprecated)",
		"lfbd": "Left Bounds",
		"liga": "Standard Ligatures",
		"ljmo": "Leading Jamo Forms",
		"lnum": "Lining Figures",
		"locl": "Localized Forms",
		"ltra": "Left-to-right alternates",
		"ltrm": "Left-to-right mirrored forms",
		"mark": "Mark Positioning",
		"med2": "Medial Forms #2",
		"medi": "Medial Forms",
		"mgrk": "Mathematical Greek",
		"mkmk": "Mark to Mark Positioning",
		"mset": "Mark Positioning via Substitution",
		"nalt": "Alternate Annotation Forms",
		"nlck": "NLC Kanji Forms",
		"nukt": "Nukta Forms",
		"numr": "Numerators",
		"onum": "Oldstyle Figures",
		"opbd": "Optical Bounds",
		"ordn": "Ordinals",
		"ornm": "Ornaments",
		"palt": "Proportional Alternate Widths",
		"pcap": "Petite Capitals",
		"pkna": "Proportional Kana",
		"pnum": "Proportional Figures",
		"pref": "Pre-Base Forms",
		"pres": "Pre-base Substitutions",
		"pstf": "Post-base Forms",
		"psts": "Post-base Substitutions",
		"pwid": "Proportional Widths",
		"qwid": "Quarter Widths",
		"rand": "Randomize",
		"rclt": "Required Contextual Alternates",
		"rkrf": "Rakar Forms",
		"rlig": "Required Ligatures",
		"rphf": "Reph Forms",
		"rtbd": "Right Bounds",
		"rtla": "Right-to-left alternates",
		"rtlm": "Right-to-left mirrored forms",
		"ruby": "Ruby Notation Forms",
		"rvrn": "Required Variation Alternates",
		"salt": "Stylistic Alternates",
		"sinf": "Scientific Inferiors",
		"size": "Optical size",
		"smcp": "Small Capitals",
		"smpl": "Simplified Forms",
		//"ss01"..."ss20": "Stylistic Set N", , // Handled in Feature.String()
		"ssty": "Math script style alternates",
		"stch": "Stretching Glyph Decomposition",
		"subs": "Subscript",
		"sups": "Superscript",
		"swsh": "Swash",
		"titl": "Titling",
		"tjmo": "Trailing Jamo Forms",
		"tnam": "Traditional Name Forms",
		"tnum": "Tabular Figures",
		"trad": "Traditional Forms",
		"twid": "Third Widths",
		"unic": "Unicase",
		"valt": "Alternate Vertical Metrics",
		"vatu": "Vattu Variants",
		"vert": "Vertical Writing",
		"vhal": "Alternate Vertical Half Metrics",
		"vivn": "Vietnamese Forms (Deprecated)",
		"vjmo": "Vowel Jamo Forms",
		"vkna": "Vertical Kana Alternates",
		"vkrn": "Vertical Kerning",
		"vpal": "Proportional Alternate Vertical Metrics",
		"vrt2": "Vertical Alternates and Rotation",
		"vrtr": "Vertical Alternates for Rotation",
		"zero": "Slashed Zero",
		"zhcn": "Simplified Chinese Forms (Deprecated)",
		"zhtw": "Traditional Chinese Forms (Deprecated)",
	}
)
